@@ -10,14 +10,25 @@ if "READTHEDOCS" not in os.environ:
     from .mesher import UnstMesh as _UnstMesh
     from .tools import WriteMesh as _WriteMesh
 
-    class parentModel(_ReadYaml, _WriteMesh, _UnstMesh, _FAMesh, _SEDMesh):
+else:
+
+    class _ReadYaml(object):
         def __init__(self):
             pass
 
+    class _UnstMesh(object):
+        def __init__(self):
+            pass
 
-else:
+    class _WriteMesh(object):
+        def __init__(self):
+            pass
 
-    class parentModel(object):
+    class _FAMesh(object):
+        def __init__(self):
+            pass
+
+    class _SEDMesh(object):
         def __init__(self):
             pass
 
@@ -25,7 +36,7 @@ else:
 MPIrank = MPI.COMM_WORLD.Get_rank()
 
 
-class Model(parentModel):
+class Model(_ReadYaml, _WriteMesh, _UnstMesh, _FAMesh, _SEDMesh):
     """
     Instantiates model object and performs surface processes evolution.
 
